<!DOCTYPE html><html><head><title>bomiot app</title><meta charset=utf-8><meta name=description content="A bomiot app"><meta name=format-detection content="telephone=no"><meta name=msapplication-tap-highlight content=no><meta name=viewport content="user-scalable=no,initial-scale=1,maximum-scale=1,minimum-scale=1,width=device-width"><link rel=icon type=image/png sizes=128x128 href="/icons/favicon-128x128.png"><link rel=icon type=image/png sizes=96x96 href="/icons/favicon-96x96.png"><link rel=icon type=image/png sizes=32x32 href="/icons/favicon-32x32.png"><link rel=icon type=image/png sizes=16x16 href="/icons/favicon-16x16.png"><link rel=icon type=image/ico href="/favicon.ico">  <script type="module" crossorigin src="/assets/index.c86eb251.js"></script>
  <link rel="stylesheet" href="/assets/index.87263133.css">
</head><body><div id=q-app></div></body></html>